==> spip_4.2.9+dfsg.orig.tar.xz: ecrire/lang/public_ay.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=ay
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Uñnaq qamawita', # MODIF
	'articles' => 'Qillqatanaka',
	'articles_auteur' => 'Qillqirin aka qillqatanakapa',
	'articles_populaires' => 'Uñt’at qillqatanaka',
	'articles_rubrique' => 'Aka t’aqat qillqatanaka',
	'aucun_article' => 'Aka utxawinx, ni kuna qillqatas utjkiti',
	'aucun_auteur' => 'Aka utxawinx janiw qillqirix utjkiti',
	'aucun_site' => 'Aka utxawinx ni kuna qamawins utjkiti',
	'aucune_breve' => 'Aka utxawinx ni kuna jisk’aptatas utjkiti',
	'aucune_rubrique' => 'Aka utxawinx ni kuna t’aqas utjkiti',
	'autres_breves' => 'Yaqha jisk’aptatanaka',
	'autres_groupes_mots_clefs' => 'Imt’aw arunakata yaqha tamanaka',
	'autres_sites' => 'Yaqha qamawinaka',

	// B
	'bonjour' => 'Kamisaki',

	// C
	'commenter_site' => 'Aka qamawxat aruskipt’aña',

	// D
	'date' => 'Uru',
	'dernier_ajout' => 'Qhipha jichhapxtawi',
	'dernieres_breves' => 'Qhipa jisk’aptatanaka',
	'derniers_articles' => 'Qhiphankir qillqatanaka',
	'derniers_commentaires' => 'Qhipha aruskipt’awinaka',
	'derniers_messages_forum' => 'Qhipha yatiyawinak aruskipawinakan yatiyata',

	// E
	'edition_mode_texte' => 'Sawutjama lurawi',
	'en_reponse' => 'Ukar jaysayaña',
	'en_resume' => 'Jisk’aptasina',
	'envoyer_message' => 'Ma yatiyaw apayaña',
	'espace_prive' => 'Ch’usawx jark’ata',

	// H
	'hierarchie_site' => 'Qamawita kamachiñawi',

	// J
	'jours' => 'Urunaka',

	// M
	'meme_auteur' => 'Pachpa qillqirita',
	'meme_rubrique' => 'Pachpa t’aqana',
	'memes_auteurs' => 'Pachpa qillqirinakata',
	'message' => 'Yatiyawi',
	'messages_forum' => 'Aruskipawit yatiyawinaka', # MODIF
	'messages_recents' => 'Amuyt’awit jichhak amuyt’awinaka',
	'mots_clefs' => 'Imt’at arunaka',
	'mots_clefs_meme_groupe' => 'Pachpa taman imt’at arunaka',

	// N
	'navigation' => 'Tuyuriwi',
	'nom' => 'Suti',
	'nouveautes' => 'Machaq yatiyawinaka',
	'nouveautes_web' => 'Web ukan machaq yatiyawinaka',
	'nouveaux_articles' => 'Machaq qillqatanaka',
	'nouvelles_breves' => 'Machaq jisk’aptatanaka',

	// P
	'page_precedente' => 'Nayrir laphi uñnaqa',
	'page_suivante' => 'Jutir laphi uñnaqa',
	'par_auteur' => 'Lurata',
	'participer_site' => 'Kunanaks lurasmaw aka jakawi qamawin ukhamarak qillqatanak lurasma akjaru qillqasisina.Ukat mäkiw mä correo electrónico qatuqata mantaw imt’atanakamampi',
	'plan_site' => 'Qamawt irpiri',
	'popularite' => 'Juk’amp uñjata',
	'poster_message' => 'Ma yatiyawi qillqaña',
	'proposer_site' => 'Aka t’aqan uskuñatakix ma qamaw amuyt’am:',

	// R
	'repondre_article' => 'Aka qillqat amuykipaña',
	'repondre_breve' => 'Aka jisk’aptata amuykipaña',
	'resultats_recherche' => 'Thaqhata uñstayi',
	'retour_debut_forums' => 'Aruskipawi qalltar kutiña',
	'rubrique' => 'T’aqa',
	'rubriques' => 'T’aqanaka',

	// S
	'signatures_petition' => 'Firmas',
	'site_realise_avec_spip' => 'Qamaw SPIP ukamp lurata',
	'sites_web' => 'web qamawinaka',
	'sous_rubriques' => 'Jutir t’aqa',
	'suite' => 'Sarantaskakiña',
	'sur_web' => 'Web ukata',
	'syndiquer_rubrique' => 'Aka t’aqa apxasiña',
	'syndiquer_site' => 't’aqat qamaw apxasiña',

	// T
	'texte_lettre_information' => 'Akax jisk’a qillqat yatiyawin qamawipawa',
	'texte_lettre_information_2' => 'Aka jisk’a qillqatxa qillqatanak ukhamaraki jisk’aptat yatiyatanak jisk’ayi', # MODIF

	// V
	'ver_imprimer' => 'Uñjat liq’suñataki',
	'voir_en_ligne' => 'Naktata uñjaña',
	'voir_squelette' => 'Aka laphi uñnaqan ch’aka ch’aka uñjaña'
);

==> spip_4.4.3+dfsg.orig.tar.xz: ecrire/lang/public_ay.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=ay
// ** ne pas modifier le fichier **

return [

	// A
	'accueil_site' => 'Uñnaq qamawita', # MODIF
	'articles' => 'Qillqatanaka',
	'articles_auteur' => 'Qillqirin aka qillqatanakapa',
	'articles_populaires' => 'Uñt’at qillqatanaka',
	'articles_rubrique' => 'Aka t’aqat qillqatanaka',
	'aucun_article' => 'Aka utxawinx, ni kuna qillqatas utjkiti',
	'aucun_auteur' => 'Aka utxawinx janiw qillqirix utjkiti',
	'aucun_site' => 'Aka utxawinx ni kuna qamawins utjkiti',
	'aucune_breve' => 'Aka utxawinx ni kuna jisk’aptatas utjkiti',
	'aucune_rubrique' => 'Aka utxawinx ni kuna t’aqas utjkiti',
	'autres_breves' => 'Yaqha jisk’aptatanaka',
	'autres_groupes_mots_clefs' => 'Imt’aw arunakata yaqha tamanaka',
	'autres_sites' => 'Yaqha qamawinaka',

	// B
	'bonjour' => 'Kamisaki',

	// C
	'commenter_site' => 'Aka qamawxat aruskipt’aña',

	// D
	'date' => 'Uru',
	'dernier_ajout' => 'Qhipha jichhapxtawi',
	'dernieres_breves' => 'Qhipa jisk’aptatanaka',
	'derniers_articles' => 'Qhiphankir qillqatanaka',
	'derniers_commentaires' => 'Qhipha aruskipt’awinaka',
	'derniers_messages_forum' => 'Qhipha yatiyawinak aruskipawinakan yatiyata',

	// E
	'edition_mode_texte' => 'Sawutjama lurawi',
	'en_reponse' => 'Ukar jaysayaña',
	'en_resume' => 'Jisk’aptasina',
	'envoyer_message' => 'Ma yatiyaw apayaña',
	'espace_prive' => 'Ch’usawx jark’ata',

	// H
	'hierarchie_site' => 'Qamawita kamachiñawi',

	// J
	'jours' => 'Urunaka',

	// M
	'meme_auteur' => 'Pachpa qillqirita',
	'meme_rubrique' => 'Pachpa t’aqana',
	'memes_auteurs' => 'Pachpa qillqirinakata',
	'message' => 'Yatiyawi',
	'messages_forum' => 'Aruskipawit yatiyawinaka', # MODIF
	'messages_recents' => 'Amuyt’awit jichhak amuyt’awinaka',
	'mots_clefs' => 'Imt’at arunaka',
	'mots_clefs_meme_groupe' => 'Pachpa taman imt’at arunaka',

	// N
	'navigation' => 'Tuyuriwi',
	'nom' => 'Suti',
	'nouveautes' => 'Machaq yatiyawinaka',
	'nouveautes_web' => 'Web ukan machaq yatiyawinaka',
	'nouveaux_articles' => 'Machaq qillqatanaka',
	'nouvelles_breves' => 'Machaq jisk’aptatanaka',

	// P
	'page_precedente' => 'Nayrir laphi uñnaqa',
	'page_suivante' => 'Jutir laphi uñnaqa',
	'par_auteur' => 'Lurata',
	'participer_site' => 'Kunanaks lurasmaw aka jakawi qamawin ukhamarak qillqatanak lurasma akjaru qillqasisina.Ukat mäkiw mä correo electrónico qatuqata mantaw imt’atanakamampi',
	'plan_site' => 'Qamawt irpiri',
	'popularite' => 'Juk’amp uñjata',
	'poster_message' => 'Ma yatiyawi qillqaña',
	'proposer_site' => 'Aka t’aqan uskuñatakix ma qamaw amuyt’am:',

	// R
	'repondre_article' => 'Aka qillqat amuykipaña',
	'repondre_breve' => 'Aka jisk’aptata amuykipaña',
	'resultats_recherche' => 'Thaqhata uñstayi',
	'retour_debut_forums' => 'Aruskipawi qalltar kutiña',
	'rubrique' => 'T’aqa',
	'rubriques' => 'T’aqanaka',

	// S
	'signatures_petition' => 'Firmas',
	'site_realise_avec_spip' => 'Qamaw SPIP ukamp lurata',
	'sites_web' => 'web qamawinaka',
	'sous_rubriques' => 'Jutir t’aqa',
	'suite' => 'Sarantaskakiña',
	'sur_web' => 'Web ukata',
	'syndiquer_rubrique' => 'Aka t’aqa apxasiña',
	'syndiquer_site' => 't’aqat qamaw apxasiña',

	// T
	'texte_lettre_information' => 'Akax jisk’a qillqat yatiyawin qamawipawa',
	'texte_lettre_information_2' => 'Aka jisk’a qillqatxa qillqatanak ukhamaraki jisk’aptat yatiyatanak jisk’ayi', # MODIF

	// V
	'ver_imprimer' => 'Uñjat liq’suñataki',
	'voir_en_ligne' => 'Naktata uñjaña',
	'voir_squelette' => 'Aka laphi uñnaqan ch’aka ch’aka uñjaña',
];
